@@ -7,6 +7,20 @@ from PyQt5.uic import loadUi
 from PyQt5.QtCore import Qt
 from PyQt5.QtCore import QThreadPool, QRunnable, QThread
 
+def tambah_angka(a,b):
+    return a+b
+
+def kali_angka(a,b):
+    return a*b
+
+def bagi_angka(a,b):
+    return a/b
+
+def kurang_angka(a,b):
+    return a-b
+
+input("Press Enter to continue...")
+
 class MyForm(QDialog):
 
     def __init__(self):
